# ====================== BEGIN GPL LICENSE BLOCK ======================
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ======================= END GPL LICENSE BLOCK ========================

import bpy

bl_info = {
    "name": "Unlooped",
    "author": "Sybren A. Stüvel",
    "description": "Prevent Blender from looping scene playback.",
    "version": (1, 0, 1),
    "blender": (4, 2, 0),
    "location": "Somewhere",
    "category": "Animation",
    "support": "COMMUNITY",
}


def on_frame_change_post(scene, depsgraph):
    if not bpy.context.screen.is_animation_playing:
        return
    if bpy.context.screen.is_looping_enabled:
        return
    if scene.frame_current != scene.frame_end:
        return

    bpy.ops.screen.animation_play()


def draw_header(header, context):
    if context.space_data.mode != "TIMELINE":
        return
    header.layout.prop(
        context.screen,
        "is_looping_enabled",
        text="",
        icon="LOOP_BACK",
    )


def register() -> None:
    bpy.app.handlers.frame_change_post.append(on_frame_change_post)

    bpy.types.Screen.is_looping_enabled = bpy.props.BoolProperty(
        name="Loop Scene Playback",
        default=True,
    )

    bpy.types.DOPESHEET_HT_header.append(draw_header)


def unregister() -> None:
    try:
        bpy.app.handlers.frame_change_post.remove(on_frame_change_post)
    except ValueError:
        pass

    try:
        del bpy.types.Screen.is_looping_enabled
    except AttributeError:
        pass

    bpy.types.DOPESHEET_HT_header.remove(draw_header)
